@@ -3,4 +3,4 @@ import Seraph.extra
 import Seraph.storage
 import Seraph.extensions
 
-__all__ = ['Seraph.main', 'Seraph.rss','Seraph.storage','Seraph.extensions']
+__all__ = ['Seraph.main','Seraph.storage','Seraph.extensions']
