@@ -30,10 +30,10 @@ def parseRss(l, info):
     feed.appendChild(rss)
     return feed.toxml()
 
-def after_built(listable=[],config={},build_loc="",logger=None):
-    with open(build_loc+"/rss.xml","w") as f:
-        f.write(parseRss(listable,config))
-    logger.info("RSS generated.")
+def after_built(**attrs):
+    with open(attrs['build_loc']+"/rss.xml","w") as f:
+        f.write(parseRss(attrs['listable'],attrs['config']))
+    attrs['logger'].info("RSS generated.")
 
-def export(listable, site, pages, newest):
+def export(**atrrs):
     return {}
